Module align_method_call_scopes

Module align_method_call_scopes 

Ensures that method call instructions have scopes such that either:

  • Both the MethodCall and its property have the same scope
  • OR neither has a scope

Ported from TypeScript src/ReactiveScopes/AlignMethodCallScopes.ts.

Functions

align_method_call_scopes
Aligns method call scopes so that either both the MethodCall result and its property operand share the same scope, or neither has a scope.