Aligns scopes of object method values to that of their enclosing object expressions. To produce a well-formed JS program in Codegen, object methods and object expressions must be in the same ReactiveBlock as object method definitions must be inlined.
Ported from TypeScript src/ReactiveScopes/AlignObjectMethodScopes.ts.
Functions
- align_
object_ method_ scopes - Aligns object method scopes so that ObjectMethod values and their enclosing ObjectExpression share the same scope.