Recursively analyzes nested function expressions and object methods to infer their aliasing effect signatures.
Ported from TypeScript src/Inference/AnalyseFunctions.ts.
Runs inferMutationAliasingEffects, deadCodeElimination, inferMutationAliasingRanges, rewriteInstructionKindsBasedOnReassignment, and inferReactiveScopeVariables on each inner function.
Functions
- analyse_
functions - Analyse all nested function expressions and object methods in
func.