Infers which variables belong to reactive scopes.
Ported from TypeScript src/ReactiveScopes/InferReactiveScopeVariables.ts.
This is the 1st of 4 passes that determine how to break a function into discrete reactive scopes (independently memoizable units of code):
- InferReactiveScopeVariables (this pass, on HIR) determines operands that mutate together and assigns them a unique reactive scope.
- AlignReactiveScopesToBlockScopes aligns reactive scopes to block scopes.
- MergeOverlappingReactiveScopes ensures scopes do not overlap.
- BuildReactiveBlocks groups the statements for each scope.
Functions
- infer_
reactive_ scope_ variables - Infer reactive scope variables for a function.